aboutsummaryrefslogtreecommitdiffstats
path: root/color.h
diff options
context:
space:
mode:
Diffstat (limited to 'color.h')
-rw-r--r--color.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/color.h b/color.h
index 043f3b07d8..449eddcea5 100644
--- a/color.h
+++ b/color.h
@@ -43,8 +43,8 @@ typedef struct {
guint16 blue;
} color_t;
/** Create a color from R, G, and B values, and do whatever toolkit-dependent
** work needs to be done.
*
* @param color the color_t to be filled
* @param red the red value for the color
@@ -53,7 +53,7 @@ typedef struct {
* @param source the GdkColor to be filled
* @return TRUE if it succeeds, FALSE if it fails
*/
-gboolean create_color(color_t *color, guint16 red, guint16 green, guint16 blue);
+gboolean initialize_color(color_t *color, guint16 red, guint16 green, guint16 blue);
/* Data for a color filter. */
typedef struct _color_filter {
@@ -43,8 +43,8 @@ typedef struct {
guint16 blue;
} color_t;
-/** Create a color from R, G, and B values, and do whatever toolkit-dependent
- ** work needs to be done.
+/** Initialize a color with R, G, and B values, including any toolkit-dependent
+ ** work that needs to be done.
*
* @param color the color_t to be filled